@@ -1,5 +1,6 @@
 /* This file is part of Step.
    Copyright (C) 2007 Vladimir Kuznetsov <ks.vladimir@gmail.com>
+   Copyright (C) 2014 Inge Wallin        <inge@lysator.liu.se>
 
    Step is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -21,7 +22,8 @@
 
 #include "worldgraphics.h"
 #include "stepgraphicsitem.h"
-#include <kaction.h>
+#include "gascreationdialog.h"
+
 
 namespace StepCore {
     class Gas;
@@ -81,7 +83,9 @@ namespace Ui {
     class WidgetCreateGasParticles;
 }
 
-class GasKDialog;
+class GasCreationDialog;
+
+
 class GasMenuHandler: public ItemMenuHandler
 {
     Q_OBJECT
@@ -104,8 +108,9 @@ protected slots:
 protected:
     StepCore::Gas* gas() const;
     Ui::WidgetCreateGasParticles* _createGasParticlesUi;
-    GasKDialog*                   _createGasParticlesDialog;
-    friend class GasKDialog;
+    GasCreationDialog  *_creationDialog;
+
+    friend class GasCreationDialog;
     static const int MAX_PARTICLES = 200;
 //    bool                      _confChanged;
 };
